'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var Keypair = require('./Keypair.cjs');

const signerIdentity = (signer, setPayer = true) => ({
  install(metaplex) {
    metaplex.identity = signer;
    if (setPayer) {
      metaplex.payer = signer;
    }
  }
});
const signerPayer = signer => ({
  install(metaplex) {
    metaplex.payer = signer;
  }
});
const generatedSignerIdentity = (setPayer = true) => ({
  install(metaplex) {
    const signer = Keypair.generateSigner(metaplex);
    metaplex.use(signerIdentity(signer, setPayer));
  }
});
const generatedSignerPayer = () => ({
  install(metaplex) {
    const signer = Keypair.generateSigner(metaplex);
    metaplex.use(signerPayer(signer));
  }
});
const keypairIdentity = (keypair, setPayer = true) => ({
  install(metaplex) {
    const signer = Keypair.createSignerFromKeypair(metaplex, keypair);
    metaplex.use(signerIdentity(signer, setPayer));
  }
});
const keypairPayer = keypair => ({
  install(metaplex) {
    const signer = Keypair.createSignerFromKeypair(metaplex, keypair);
    metaplex.use(signerPayer(signer));
  }
});

exports.generatedSignerIdentity = generatedSignerIdentity;
exports.generatedSignerPayer = generatedSignerPayer;
exports.keypairIdentity = keypairIdentity;
exports.keypairPayer = keypairPayer;
exports.signerIdentity = signerIdentity;
exports.signerPayer = signerPayer;
//# sourceMappingURL=SignerPlugins.cjs.map
